@@ -5,6 +5,7 @@
 # @desc    :
 """
 import copy
+import json
 import os
 
 import tablib
@@ -15,8 +16,8 @@ from api_test_ez.core.case.frame.frame_unittest import UnitHttpFrame
 from api_test_ez.core.case.http.request import Request
 from api_test_ez.core.case.http.response import EzResponse
 
-from api_test_ez.ez import Log, Http
-from api_test_ez.project import get_ez_config, Project
+from api_test_ez.ez import Http
+from api_test_ez.project import Project
 
 
 def load_test_data(data_filename):
@@ -115,7 +116,7 @@ class UnitCase(UnitHttpFrame, metaclass=CaseMetaclass):
 
     def __init__(self, methodName):
         self.request = Request(http=Http())
-        self.response = EzResponse()
+        self.response = EzResponse(logger=self.logger)
         self.request.owner = methodName
         self.response.owner = methodName
         self.initRequest(methodName)
@@ -140,6 +141,8 @@ class UnitCase(UnitHttpFrame, metaclass=CaseMetaclass):
         return self.request
 
     def doRequest(self, request=None):
+        if request:
+            self.request.set(request)
         # Prepare request
         body_type = "data"
         http = self.request.http
@@ -149,9 +152,9 @@ class UnitCase(UnitHttpFrame, metaclass=CaseMetaclass):
         body = self.request.body
         if body:
             try:
-                body = ast.literal_eval(body)
+                body = json.loads(body)
                 body_type = "json"
-            except SyntaxError:
+            except json.JSONDecodeError:
                 pass
 
         # Request start
